@@ -13,15 +13,14 @@ from .helper import filter_none, format_media_prompt
 from .base_provider import AsyncGeneratorProvider, ProviderModelMixin
 from ..typing import AsyncResult, Messages, MediaListType
 from ..image import is_data_an_audio
-from ..errors import ModelNotFoundError, ResponseError, MissingAuthError
-from ..requests import see_stream
+from ..errors import ModelNotFoundError, MissingAuthError
 from ..requests.raise_for_status import raise_for_status
 from ..requests.aiohttp import get_connector
-from ..image.copy_images import save_response_media
 from ..image import use_aspect_ratio
-from ..providers.response import FinishReason, Usage, ToolCalls, ImageResponse, Reasoning, TitleGeneration, SuggestedFollowups, ProviderInfo, AudioResponse
+from ..providers.response import ImageResponse, Reasoning, TitleGeneration, SuggestedFollowups
 from ..tools.media import render_messages
 from ..config import STATIC_URL
+from .template.OpenaiTemplate import read_response
 from .. import debug
 
 DEFAULT_HEADERS = {
@@ -65,7 +64,7 @@ class PollinationsAI(AsyncGeneratorProvider, ProviderModelMixin):
     label = "Pollinations AI"
     url = "https://pollinations.ai"
     login_url = "https://auth.pollinations.ai"
-
+    active_by_default = True
     working = True
     supports_system_message = True
     supports_message_history = True
@@ -81,8 +80,9 @@ class PollinationsAI(AsyncGeneratorProvider, ProviderModelMixin):
     default_image_model = "flux"
     default_vision_model = default_model
     default_audio_model = "openai-audio"
+    default_voice = "alloy"
     text_models = [default_model, "evil"]
-    image_models = [default_image_model, "kontext", "gptimage"]
+    image_models = [default_image_model, "turbo", "kontext", "gptimage", "transparent"]
     audio_models = {default_audio_model: []}
     vision_models = [default_vision_model]
     _models_loaded = False
@@ -253,8 +253,6 @@ class PollinationsAI(AsyncGeneratorProvider, ProviderModelMixin):
             cache = kwargs.get("action") == "next"
         if extra_body is None:
             extra_body = {}
-        # Load model list
-        cls.get_models()
         if not model:
             has_audio = "audio" in kwargs or "audio" in kwargs.get("modalities", [])
             if not has_audio and media is not None:
@@ -269,7 +267,7 @@ class PollinationsAI(AsyncGeneratorProvider, ProviderModelMixin):
             pass
         if model in cls.image_models:
             async for chunk in cls._generate_image(
-                model=model,
+                model="gptimage" if model == "transparent" else model,
                 prompt=format_media_prompt(messages, prompt),
                 media=media,
                 proxy=proxy,
@@ -282,7 +280,7 @@ class PollinationsAI(AsyncGeneratorProvider, ProviderModelMixin):
                 private=private,
                 enhance=enhance,
                 safe=safe,
-                transparent=transparent,
+                transparent=transparent or model == "transparent",
                 n=n,
                 referrer=referrer,
                 api_key=api_key
@@ -350,6 +348,7 @@ class PollinationsAI(AsyncGeneratorProvider, ProviderModelMixin):
             "private": str(private).lower(),
             "enhance": str(enhance).lower(),
             "safe": str(safe).lower(),
+            "referrer": referrer
         }
         if transparent:
             params["transparent"] = "true"
@@ -446,14 +445,14 @@ class PollinationsAI(AsyncGeneratorProvider, ProviderModelMixin):
             extra_body.update({param: kwargs[param] for param in extra_parameters if param in kwargs})
             if model in cls.audio_models:
                 if "audio" in extra_body and extra_body.get("audio", {}).get("voice") is None:
-                    extra_body["audio"]["voice"] = cls.audio_models[model][0]
+                    extra_body["audio"]["voice"] = cls.default_voice
                 elif "audio" not in extra_body:
-                    extra_body["audio"] = {"voice": cls.audio_models[model][0]}
+                    extra_body["audio"] = {"voice": cls.default_voice}
                 if extra_body.get("audio", {}).get("format") is None:
                     extra_body["audio"]["format"] = "mp3"
+                    stream = False
                 if "modalities" not in extra_body:
                     extra_body["modalities"] = ["text", "audio"]
-                stream = False
             data = filter_none(
                 messages=list(render_messages(messages, media)),
                 model=model,
@@ -464,6 +463,7 @@ class PollinationsAI(AsyncGeneratorProvider, ProviderModelMixin):
                 response_format=response_format,
                 stream=stream,
                 seed=None if model =="grok" else seed,
+                referrer=referrer,
                 **extra_body
             )
             headers = {"referer": referrer}
@@ -472,40 +472,13 @@ class PollinationsAI(AsyncGeneratorProvider, ProviderModelMixin):
             async with session.post(cls.openai_endpoint, json=data, headers=headers) as response:
                 if response.status in (400, 500):
                     debug.error(f"Error: {response.status} - Bad Request: {data}")
-                await raise_for_status(response)
-                if response.headers["content-type"].startswith("text/plain"):
-                    yield await response.text()
-                    return
-                elif response.headers["content-type"].startswith("text/event-stream"):
-                    reasoning = False
-                    model_returned = False
-                    full_content = ""
-                    async for result in see_stream(response.content):
-                        if "error" in result:
-                            raise ResponseError(result["error"].get("message", result["error"]))
-                        if not model_returned and result.get("model"):
-                            yield ProviderInfo(**cls.get_dict(), model=result.get("model"))
-                            model_returned = True
-                        if result.get("usage") is not None:
-                            yield Usage(**result["usage"])
-                        choices = result.get("choices", [{}])
-                        choice = choices.pop() if choices else {}
-                        content = choice.get("delta", {}).get("content")
-                        if content:
-                            yield content
-                            full_content += content
-                        tool_calls = choice.get("delta", {}).get("tool_calls")
-                        if tool_calls:
-                            yield ToolCalls(choice["delta"]["tool_calls"])
-                        reasoning_content = choice.get("delta", {}).get("reasoning_content")
-                        if reasoning_content:
-                            reasoning = True
-                            yield Reasoning(reasoning_content)
-                        finish_reason = choice.get("finish_reason")
-                        if finish_reason:
-                            yield FinishReason(finish_reason)
-                    if reasoning:
-                        yield Reasoning(status="")
+                full_resposne = []
+                async for chunk in read_response(response, stream, format_media_prompt(messages), cls.get_dict(), kwargs.get("download_media", True)):
+                    if isinstance(chunk, str):
+                        full_resposne.append(chunk)
+                    yield chunk
+                if full_resposne:
+                    full_content = "".join(full_resposne)
                     if kwargs.get("action") == "next":
                         tool_messages = []
                         for message in messages:
@@ -536,34 +509,4 @@ class PollinationsAI(AsyncGeneratorProvider, ProviderModelMixin):
                                     if arguments.get("followups"):
                                         yield SuggestedFollowups(arguments.get("followups"))
                             except Exception as e:
-                                debug.error("Error generating title and followups:", e)
-                elif response.headers["content-type"].startswith("application/json"):
-                    prompt = format_media_prompt(messages)
-                    result = await response.json()
-                    if result.get("model"):
-                        yield ProviderInfo(**cls.get_dict(), model=result.get("model"))
-                    if "choices" in result:
-                        choice = result["choices"][0]
-                        message = choice.get("message", {})
-                        content = message.get("content", "")
-                        if content:
-                            yield content
-                        if "tool_calls" in message:
-                            yield ToolCalls(message["tool_calls"])
-                        audio = message.get("audio", {})
-                        if "data" in audio:
-                            async for chunk in save_response_media(audio["data"], prompt, [model, extra_body.get("audio", {}).get("voice")]):
-                                yield chunk
-                        if "transcript" in audio:
-                            yield "\n\n"
-                            yield audio["transcript"]
-                    else:
-                        raise ResponseError(result)
-                    if result.get("usage") is not None:
-                        yield Usage(**result["usage"])
-                    finish_reason = choice.get("finish_reason")
-                    if finish_reason:
-                        yield FinishReason(finish_reason)
-                else:
-                    async for chunk in save_response_media(response, prompt, [model, extra_body.get("audio", {}).get("voice")]):
-                        yield chunk
\ No newline at end of file
+                                debug.error("Error generating title and followups:", e)
\ No newline at end of file
