@@ -79,7 +79,6 @@ class LMArenaBeta(AsyncGeneratorProvider, ProviderModelMixin, AuthFileMixin):
     url = "https://beta.lmarena.ai"
     api_endpoint = "https://beta.lmarena.ai/api/stream/create-evaluation"
     working = True
-    active_by_default = has_nodriver
 
     default_model = list(text_models.keys())[0]
     models = list(text_models) + list(image_models)
@@ -121,6 +120,9 @@ class LMArenaBeta(AsyncGeneratorProvider, ProviderModelMixin, AuthFileMixin):
             model = image_models[model]
         elif model in text_models:
             model = text_models[model]
+        elif model in cls.model_aliases:
+            model = cls.model_aliases[model]
+            debug.log(f"Using model alias: {model}")
         else:
             raise ModelNotFoundError(f"Model '{model}' is not supported by LMArena Beta.")
         userMessageId = str(uuid.uuid4())
