@@ -15,6 +15,7 @@ from .ChatGptt          import ChatGptt
 from .DDG               import DDG
 from .Equing            import Equing
 from .FlowGpt           import FlowGpt
+from .FreeGpt           import FreeGpt
 from .FreeNetfly        import FreeNetfly
 from .FreeRouter        import FreeRouter
 from .Glider            import Glider
@@ -33,3 +34,5 @@ from .Theb              import Theb
 from .TypeGPT           import TypeGPT
 from .Upstage           import Upstage
 from .Vercel            import Vercel
+from .Websim            import Websim
+
