@@ -9,7 +9,7 @@ import asyncio
 import shutil
 import random
 import datetime
-import base64
+from hashlib import sha256
 from urllib.parse import quote_plus
 from flask import Flask, Response, redirect, request, jsonify, send_from_directory
 from werkzeug.exceptions import NotFound
@@ -29,8 +29,7 @@ try:
 except ImportError as e:
     has_markitdown = False
 try:
-    from cryptography.hazmat.primitives import serialization
-    from cryptography.hazmat.primitives.asymmetric import padding, rsa
+    from .crypto import rsa, serialization, create_or_read_keys, decrypt_data, encrypt_data, get_session_key
     has_crypto = True
 except ImportError:
     has_crypto = False
@@ -46,7 +45,6 @@ from ...image import is_allowed_extension, process_image, MEDIA_TYPE_MAP
 from ...cookies import get_cookies_dir
 from ...image.copy_images import secure_filename, get_source_url, get_media_dir, copy_media
 from ...client.service import get_model_and_provider
-from ... import ChatCompletion
 from ... import models
 from .api import Api
 
@@ -81,19 +79,13 @@ class Backend_Api(Api):
         self.chat_cache = {}
 
         if has_crypto:
-            private_key_obj = rsa.generate_private_key(public_exponent=65537, key_size=2048)
+            private_key_obj = get_session_key()
             public_key_obj = private_key_obj.public_key()
             public_key_pem = public_key_obj.public_bytes(
                 encoding=serialization.Encoding.PEM,
                 format=serialization.PublicFormat.SubjectPublicKeyInfo
             )
-
-            def decrypt_data(encrypted_data: str) -> str:
-                decrypted = private_key_obj.decrypt(
-                    base64.b64decode(encrypted_data),
-                    padding.PKCS1v15()
-                )
-                return decrypted.decode()
+            sub_private_key, sub_public_key = create_or_read_keys()
 
             def validate_secret(secret: str) -> bool:
                 """
@@ -106,8 +98,9 @@ class Backend_Api(Api):
                     bool: True if the secret is valid, False otherwise.
                 """
                 try:
-                    decrypted_secret = base64.b64decode(decrypt_data(secret).encode()).decode()
-                    return int(decrypted_secret) >= time.time() - 3
+                    decrypted_secret = decrypt_data(sub_private_key, decrypt_data(private_key_obj, secret))
+                    timediff = time.time() - int(decrypted_secret)
+                    return timediff <= 3 and timediff >= 0
                 except Exception as e:
                     logger.error(f"Secret validation failed: {e}")
                     return False
@@ -117,7 +110,7 @@ class Backend_Api(Api):
                 # Send the public key to the client for encryption
                 return jsonify({
                     "public_key": public_key_pem.decode(),
-                    "data": base64.b64encode(str(int(time.time())).encode()).decode()
+                    "data": encrypt_data(sub_public_key, str(int(time.time())))
                 })
 
         @app.route('/backend-api/v2/models', methods=['GET'])
@@ -192,9 +185,7 @@ class Backend_Api(Api):
                 else:
                     json_data["provider"] = models.HuggingFace
             if app.demo:
-                ip = request.headers.get("X-Forwarded-For", "")
-                user = request.headers.get("Cf-Ipcountry", "")
-                json_data["user"] = request.headers.get("x_user", f"{user}:{ip}")
+                json_data["user"] = request.headers.get("x-user", "error")
                 json_data["referer"] = request.headers.get("referer", "")
                 json_data["user-agent"] = request.headers.get("user-agent", "")
             kwargs = self._prepare_conversation_kwargs(json_data)
@@ -220,6 +211,12 @@ class Backend_Api(Api):
             with cache_file.open("a" if cache_file.exists() else "w") as f:
                 f.write(f"{json.dumps(request.json)}\n")
             return {}
+    
+        @app.route('/backend-api/v2/usage/<date>', methods=['GET'])
+        def get_usage(date: str):
+            cache_dir = Path(get_cookies_dir()) / ".usage"
+            cache_file = cache_dir / f"{date}.jsonl"
+            return cache_file.read_text() if cache_file.exists() else (jsonify({"error": {"message": "No usage data found for this date"}}), 404)
 
         @app.route('/backend-api/v2/log', methods=['POST'])
         def add_log():
@@ -442,18 +439,21 @@ class Backend_Api(Api):
                 if is_media:
                     os.makedirs(media_dir, exist_ok=True)
                     newfile = os.path.join(media_dir, filename)
-                    if result:
-                        media.append({"name": filename, "text": result})
-                    else:
-                        media.append({"name": filename})
+                    image_size = {}
                     if has_pillow:
                         try:
                             image = Image.open(copyfile)
+                            width, height = image.size
+                            image_size = {"width": width, "height": height}
                             thumbnail_dir = os.path.join(bucket_dir, "thumbnail")
                             os.makedirs(thumbnail_dir, exist_ok=True)
                             process_image(image, save=os.path.join(thumbnail_dir, filename))
                         except Exception as e:
                             logger.exception(e)
+                    if result:
+                        media.append({"name": filename, "text": result, **image_size})
+                    else:
+                        media.append({"name": filename, **image_size})
                 elif is_supported and not result:
                     newfile = os.path.join(bucket_dir, filename)
                     filenames.append(filename)
