@@ -10,9 +10,9 @@ from ..providers.retry_provider import IterListProvider
 from ..Provider.needs_auth import OpenaiChat, CopilotAccount
 from ..Provider.hf_space import HuggingSpace
 from ..Provider import Cloudflare, Gemini, GeminiPro, Grok, DeepSeekAPI, PerplexityLabs, LambdaChat, PollinationsAI, PuterJS
-from ..Provider import Microsoft_Phi_4_Multimodal, DeepInfraChat, Blackbox, OIVSCodeSer2, OIVSCodeSer0501, TeachAnything
-from ..Provider import Together, WeWordle, Yqcloud, Chatai, Free2GPT, ImageLabs, LegacyLMArena, LMArenaBeta
-from ..Provider import EdgeTTS, gTTS, MarkItDown, OpenAIFM, Video
+from ..Provider import Microsoft_Phi_4_Multimodal, DeepInfraChat, Blackbox, OIVSCodeSer0501, OIVSCodeSer2, TeachAnything, OperaAria, Startnest
+from ..Provider import Together, WeWordle, Yqcloud, Chatai, ImageLabs, LegacyLMArena, LMArenaBeta, Free2GPT
+from ..Provider import EdgeTTS, gTTS, MarkItDown, OpenAIFM, PenguinAI
 from ..Provider import HarProvider, HuggingFace, HuggingFaceMedia
 from .base_provider import AsyncGeneratorProvider, ProviderModelMixin
 from .. import Provider
@@ -24,8 +24,8 @@ PROVIERS_LIST_1 = [
     CopilotAccount, OpenaiChat, Cloudflare, PerplexityLabs, Gemini, Grok, DeepSeekAPI, Blackbox, OpenAIFM,
     OIVSCodeSer2, OIVSCodeSer0501, TeachAnything, WeWordle, Yqcloud, Chatai, Free2GPT, ImageLabs,
     # Has lazy loading model lists
-    PollinationsAI, HarProvider, LegacyLMArena, LMArenaBeta, LambdaChat, DeepInfraChat,
-    HuggingSpace, HuggingFace, HuggingFaceMedia, GeminiPro, Together, PuterJS
+    PollinationsAI, HarProvider, LegacyLMArena, LMArenaBeta, LambdaChat, DeepInfraChat, PenguinAI,
+    HuggingSpace, HuggingFace, HuggingFaceMedia, GeminiPro, Together, PuterJS, OperaAria, Startnest
 ]
 
 PROVIERS_LIST_2 = [
@@ -342,6 +342,7 @@ class AnyModelProviderMixin(ProviderModelMixin):
 
 class AnyProvider(AsyncGeneratorProvider, AnyModelProviderMixin):
     working = True
+    active_by_default = True
 
     @classmethod
     async def create_async_generator(
