@@ -68,12 +68,11 @@ def get_system_prompt(messages: Messages) -> str:
 
 def get_last_user_message(messages: Messages) -> str:
     user_messages = []
-    last_message = None if len(messages) == 0 else messages[-1]
-    messages = messages.copy()
-    while last_message is not None and messages:
-        last_message = messages.pop()
-        if last_message["role"] == "user":
-            content = to_string(last_message.get("content")).strip()
+    for message in messages[::-1]:
+        if message.get("role") == "user" or not user_messages:
+            if message.get("role") != "user":
+                continue
+            content = to_string(message.get("content")).strip()
             if content:
                 user_messages.append(content)
         else:
