@@ -7,12 +7,13 @@ from pathlib import Path
 from typing import Iterator, Optional, AsyncIterator
 from aiohttp import ClientSession, ClientError, ClientResponse, ClientTimeout
 import urllib.parse
-from urllib.parse import unquote
 import time
 import zipfile
 import asyncio
 import hashlib
 import base64
+import tempfile
+import shutil
 
 try:
     import PyPDF2
@@ -67,9 +68,14 @@ try:
     has_beautifulsoup4 = True
 except ImportError:
     has_beautifulsoup4 = False
+try:
+    from markitdown import MarkItDown
+    has_markitdown = True
+except ImportError:
+    has_markitdown = False
 
 from .web_search import scrape_text
-from ..cookies import get_cookies_dir
+from ..files import secure_filename, get_bucket_dir
 from ..image import is_allowed_extension
 from ..requests.aiohttp import get_connector
 from ..providers.asyncio import to_sync_generator
@@ -81,19 +87,6 @@ PLAIN_CACHE = "plain.cache"
 DOWNLOADS_FILE = "downloads.json"
 FILE_LIST = "files.txt"
 
-def secure_filename(filename: str) -> str:
-    if filename is None:
-        return None
-    # Keep letters, numbers, basic punctuation and all Unicode chars
-    filename = re.sub(
-        r'[^\w.,_+-]+',
-        '_', 
-        unquote(filename).strip(), 
-        flags=re.UNICODE
-    )
-    filename = filename[:100].strip(".,_-+")
-    return filename
-
 def supports_filename(filename: str):
     if filename.endswith(".pdf"):
         if has_pypdf2:
@@ -129,16 +122,6 @@ def supports_filename(filename: str):
             return True
     return False
 
-def get_bucket_dir(*parts):
-    return os.path.join(get_cookies_dir(), "buckets", *[secure_filename(part) for part in parts if part])
-
-def get_buckets():
-    buckets_dir = os.path.join(get_cookies_dir(), "buckets")
-    try:
-        return [d for d in os.listdir(buckets_dir) if os.path.isdir(os.path.join(buckets_dir, d))]
-    except OSError:
-        return None
-
 def spacy_refine_chunks(source_iterator):
     if not has_spacy:
         raise MissingRequirementsError(f'Install "spacy" requirements | pip install -U g4f[files]')
@@ -164,8 +147,10 @@ def get_filenames(bucket_dir: Path):
             return [filename.strip() for filename in f.readlines()]
     return []
 
-def stream_read_files(bucket_dir: Path, filenames: list, delete_files: bool = False) -> Iterator[str]:
+def stream_read_files(bucket_dir: Path, filenames: list[str], delete_files: bool = False) -> Iterator[str]:
     for filename in filenames:
+        if filename.startswith(DOWNLOADS_FILE):
+            continue
         file_path: Path = bucket_dir / filename
         if not file_path.exists() or file_path.lstat().st_size <= 0:
             continue
@@ -187,7 +172,7 @@ def stream_read_files(bucket_dir: Path, filenames: list, delete_files: bool = Fa
                                 else:
                                     os.unlink(filepath)
             continue
-        yield f"```{filename}\n"        
+        yield f"<!-- File: {filename} -->\n"
         if has_pypdf2 and filename.endswith(".pdf"):
             try:
                 reader = PyPDF2.PdfReader(file_path)
@@ -225,8 +210,8 @@ def stream_read_files(bucket_dir: Path, filenames: list, delete_files: bool = Fa
         elif has_beautifulsoup4 and filename.endswith(".html"):
             yield from scrape_text(file_path.read_text(errors="ignore"))
         elif extension in PLAIN_FILE_EXTENSIONS:
-            yield file_path.read_text(errors="ignore")
-        yield f"\n```\n\n"
+            yield file_path.read_text(errors="ignore").strip()
+        yield f"\n<-- End -->\n\n"
 
 def cache_stream(stream: Iterator[str], bucket_dir: Path) -> Iterator[str]:
     cache_file = bucket_dir / PLAIN_CACHE
@@ -334,6 +319,13 @@ def split_file_by_size_and_newline(input_filename, output_dir, chunk_size_bytes=
             with open(output_filename, 'w', encoding='utf-8') as outfile:
                 outfile.write(current_chunk)
 
+def get_filename_from_url(url: str, extension: str = ".md") -> str:
+    parsed_url = urllib.parse.urlparse(url)
+    sha256_hash = hashlib.sha256(url.encode()).digest()
+    base32_encoded = base64.b32encode(sha256_hash).decode()
+    url_hash = base32_encoded[:24].lower()
+    return f"{parsed_url.netloc}+{parsed_url.path[1:].replace('/', '_')}+{url_hash}{extension}"
+
 async def get_filename(response: ClientResponse) -> str:
     """
     Attempts to extract a filename from an aiohttp response. Prioritizes Content-Disposition, then URL.
@@ -359,11 +351,7 @@ async def get_filename(response: ClientResponse) -> str:
     if content_type and url:
         extension = await get_file_extension(response)
         if extension:
-            parsed_url = urllib.parse.urlparse(url)
-            sha256_hash = hashlib.sha256(url.encode()).digest()
-            base32_encoded = base64.b32encode(sha256_hash).decode()
-            url_hash = base32_encoded[:24].lower()
-            return f"{parsed_url.netloc}+{parsed_url.path[1:].replace('/', '_')}+{url_hash}{extension}"
+            return get_filename_from_url(url, extension)
 
     return None
 
@@ -437,17 +425,30 @@ async def download_urls(
 ) -> AsyncIterator[str]:
     if lock is None:
         lock = asyncio.Lock()
+    md = MarkItDown()
     async with ClientSession(
         connector=get_connector(proxy=proxy),
         timeout=ClientTimeout(timeout)
     ) as session:
         async def download_url(url: str, max_depth: int) -> str:
+            text_content = None
+            if has_markitdown:
+                try:
+                    text_content = md.convert(url).text_content
+                    if text_content:
+                        filename = get_filename_from_url(url)
+                        target = bucket_dir / filename
+                        text_content = f"{text_content.strip()}\n\nSource: {url}\n"
+                        target.write_text(text_content, errors="replace")
+                        return filename
+                except Exception as e:
+                    debug.log(f"Failed to convert URL to text: {type(e).__name__}: {e}")
             try:
                 async with session.get(url) as response:
                     response.raise_for_status()
                     filename = await get_filename(response)
                     if not filename:
-                        print(f"Failed to get filename for {url}")
+                        debug.log(f"Failed to get filename for {url}")
                         return None
                     if not is_allowed_extension(filename) and not supports_filename(filename) or filename == DOWNLOADS_FILE:
                         return None
@@ -578,4 +579,11 @@ async def get_async_streaming(bucket_dir: str, delete_files = False, refine_chun
     except Exception as e:
         if event_stream:
             yield f'data: {json.dumps({"error": {"message": str(e)}})}\n\n'
-        raise e
\ No newline at end of file
+        raise e
+
+def get_tempfile(file, suffix: str = None):
+    copyfile = tempfile.NamedTemporaryFile(suffix=suffix, delete=False)
+    shutil.copyfileobj(file, copyfile)
+    copyfile.close()
+    file.close()
+    return copyfile.name
\ No newline at end of file
